@@ -6,9 +6,10 @@ Free as freedom will be 26/8/2016
 @author: luisza
 '''
 
-from django.conf.urls import url, include
+from django.conf.urls import include
 from django.contrib.auth.decorators import login_required
 from django.http.response import HttpResponseRedirect, HttpResponseForbidden
+from django.urls import re_path
 from django.urls.base import reverse_lazy, reverse
 from django.urls.exceptions import NoReverseMatch
 from django.views import View
@@ -19,7 +20,7 @@ from .filter import get_filters
 
 from django.contrib.auth.models import Permission
 from django.contrib.contenttypes.models import ContentType
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.db.models.query_utils import Q
 from django.shortcuts import get_object_or_404
 
@@ -199,7 +200,7 @@ class CRUDView(object):
         .. code:: python
             myview = Myclass()
             urlpatterns = [
-                url('path', include(myview.get_urls()))  # also support
+                re_path('path', include(myview.get_urls()))  # also support
                                                          # namespace
             ]
 
@@ -276,7 +277,7 @@ class CRUDView(object):
 
             myview = Myclass()
             urlpatterns = [
-                url('path', include(myview.get_urls(),
+                re_path('path', include(myview.get_urls(),
                                     namespace="mynamespace"))
             ]
 
@@ -714,30 +715,30 @@ class CRUDView(object):
                                  self.model.__name__.lower())
         myurls = []
         if 'list' in self.views_available:
-            myurls.append(url("^%s/list$" % (base_name,),
+            myurls.append(re_path("^%s/list$" % (base_name,),
                               self.list,
                               name=utils.crud_url_name(
                                   self.model, 'list', prefix=self.urlprefix)))
         if 'create' in self.views_available:
-            myurls.append(url("^%s/create$" % (base_name,),
+            myurls.append(re_path("^%s/create$" % (base_name,),
                               self.create,
                               name=utils.crud_url_name(
                                   self.model, 'create', prefix=self.urlprefix))
                           )
         if 'detail' in self.views_available:
-            myurls.append(url('^%s/(?P<pk>[^/]+)$' % (base_name,),
+            myurls.append(re_path('^%s/(?P<pk>[^/]+)$' % (base_name,),
                               self.detail,
                               name=utils.crud_url_name(
                                   self.model, 'detail', prefix=self.urlprefix))
                           )
         if 'update' in self.views_available:
-            myurls.append(url("^%s/(?P<pk>[^/]+)/update$" % (base_name,),
+            myurls.append(re_path("^%s/(?P<pk>[^/]+)/update$" % (base_name,),
                               self.update,
                               name=utils.crud_url_name(
                                   self.model, 'update', prefix=self.urlprefix))
                           )
         if 'delete' in self.views_available:
-            myurls.append(url(r"^%s/(?P<pk>[^/]+)/delete$" % (base_name,),
+            myurls.append(re_path(r"^%s/(?P<pk>[^/]+)/delete$" % (base_name,),
                               self.delete,
                               name=utils.crud_url_name(
                                   self.model, 'delete', prefix=self.urlprefix))
@@ -759,13 +760,13 @@ class CRUDView(object):
                 self.inlines[i] = klass
                 if self.namespace:
                     dev.append(
-                        url('^inline/',
+                        re_path('^inline/',
                             include(klass.get_urls(),
                                     namespace=self.namespace))
                     )
                 else:
                     dev.append(
-                        url('^inline/', include(klass.get_urls()))
+                        re_path('^inline/', include(klass.get_urls()))
 
                     )
         return dev
