@@ -138,7 +138,7 @@ class FileInput(DJFileInput):
     def __init__(self, attrs=None, extraskwargs=True):
         if extraskwargs:
             attrs = update_kwargs(attrs, self.__class__.__name__,
-                                  base_class='djgentelella-file-input form-control')
+                                  base_class='djgentelella-file-inputt form-control')
         if 'data-href' not in attrs:
             attrs.update({'data-href': reverse_lazy('upload_file_view')})
         if 'data-done' not in attrs:
@@ -241,6 +241,7 @@ class DateTimeInput(DJDateTimeInput, DateFormatConverter):
     template_name = 'gentelella/widgets/datetime.html'
 
     def __init__(self, attrs=None, format=None):
+
         attrs = update_kwargs(attrs, self.__class__.__name__)
         format_js = self.get_format_js()
         attrs['data-format'] = format_js
@@ -536,3 +537,12 @@ class PhoneNumberMaskInput(TextInput):
         attrs = update_kwargs(attrs, self.__class__.__name__)
 
         super().__init__(attrs)
+
+class PhoneNumberMaskInput(TextInput):
+    input_type = 'text'
+    template_name = 'gentelella/widgets/phone_number_input_mask.html'
+
+    def __init__(self, attrs=None):
+        attrs = update_kwargs(attrs, self.__class__.__name__)
+
+        super().__init__(attrs)
